==> Code%20v2.10.4.zip: Code v2.10.4/application/language/english/web_labels_lang.php <==
<?php defined('BASEPATH') OR exit('No direct script access allowed');


$lang['language_id'] = "1";
$lang['menu'] = "Menu";
$lang['products'] = "Products";
$lang['shop'] = "Shop";
$lang['my_account'] = "My Account";
$lang['my_orders'] = "My Orders";
$lang['favorite'] = "Favorite";
$lang['sellers'] = "Sellers";
$lang['login'] = "Sign In";
$lang['register'] = "Sign Up Here";
$lang['about_us'] = "About Us";
$lang['contact_us'] = "Contact Us";
$lang['logout'] = "Logout";
$lang['language'] = "Language";
$lang['shopping_cart'] = "Shopping Cart";
$lang['close'] = "Close";
$lang['return_to_shop'] = "Return to Shop";
$lang['empty_cart_message'] = "Your Cart Is Empty";
$lang['view_cart'] = "View Cart";
$lang['faq'] = "FAQs";
$lang['compare'] = "Compare";
$lang['pages'] = "Pages";
$lang['social_media'] = "Social Media";
$lang['terms_and_condition'] = "Terms & Condition";
$lang['privacy_policy'] = "Privacy Policy";
$lang['reviews'] = "Reviews";
$lang['add_to_cart'] = "Add to Cart";
$lang['add_to_favorite'] = "Add to Favorite";
$lang['cancel'] = "Cancel";
$lang['send_otp'] = "Send OTP";
$lang['submit'] = "Submit";
$lang['home'] = "Home";
$lang['name'] = "Name";
$lang['mobile_number'] = "Mobile Number";
$lang['address'] = "Address";
$lang['city'] = "City";
$lang['select_city'] = "Select City";
$lang['select_area'] = "Select Area";
$lang['area'] = "Area";
$lang['pincode'] = "Pincode";
$lang['state'] = "State";
$lang['country'] = "Country";
$lang['type'] = "Type";
$lang['office'] = "Office";
$lang['other'] = "Other";
$lang['alternate_mobile'] = "Alternate Mobile";
$lang['landmark'] = "Landmark";
$lang['action'] = "Action";
$lang['edit_address'] = "Edit Address";
$lang['image'] = "Image";
$lang['images'] = "Images";
$lang['price'] = "Price";
$lang['quantity'] = "Quantity";
$lang['total'] = "Total";
$lang['save_for_later'] = "Save For Later";
$lang['remove'] = "Remove";
$lang['subtotal'] = "Subtotal";
$lang['tax'] = "Tax";
$lang['delivery_charge'] = "Delivery Charge";
$lang['grand_total'] = "Grand Total";
$lang['checkout'] = "Checkout";
$lang['move_to_cart'] = "Move to cart";
$lang['category'] = "Category";
$lang['cart'] = "Cart";
$lang['your_cart'] = "Your cart";
$lang['promo_code'] = "Promo code";
$lang['redeem'] = "Redeem";
$lang['clear'] = "Clear";
$lang['billing_address'] = "Billing address";
$lang['preferred_delivery_date_time'] = "Preferred Delivery Date / Time";
$lang['select_payment_method'] = "Select Payment Method";
$lang['cash_on_delivery'] = "Cash On Delivery";
$lang['create_a_new_address'] = "Create a New Address";
$lang['shipping_address'] = "Shipping Address";
$lang['save'] = "Save";
$lang['username'] = "Username";
$lang['email'] = "Email";
$lang['subject'] = "Subject";
$lang['message'] = "Message";
$lang['send_message'] = "Send Message";
$lang['dashboard'] = "Dashboard";
$lang['profile'] = "Profile";
$lang['orders'] = "Orders";
$lang['notification'] = "Notification";
$lang['wallet'] = "Wallet";
$lang['transaction'] = "Transaction";
$lang['no_favorite_product_message'] = "No Favorite Products Found";
$lang['amazing_categories'] = "Amazing Categories";
$lang['view_more'] = "View More";
$lang['mobile_app'] = "Mobile App";
$lang['order_id'] = "Order ID";
$lang['place_on'] = "Place On";
$lang['invoice'] = "Invoice";
$lang['back_to_list'] = "Back to List";
$lang['return'] = "Return";
$lang['shipping_details'] = "Shipping Details";
$lang['total_order_price'] = "Total Order Price";
$lang['promocode_discount'] = "Promocode Discount";
$lang['wallet_used'] = "Wallet Used";
$lang['final_total'] = "Final Total";
$lang['view_details'] = "View Details";
$lang['payment_cancelled'] = "Payment Cancelled / Failed";
$lang['payment_cancelled_message'] = "It seems like payment process is failed or cancelled.Please Try again.";
$lang['payment_completed'] = "Payment Complete";
$lang['payment_completed_message'] = "Payment Completed Succesfully";
$lang['thank_you_for_shopping_with_us'] = "Thank you for Shopping with Us";
$lang['filter'] = "Filter";
$lang['top_rated'] = "Top Rated";
$lang['newest_first'] = "Newest First";
$lang['oldest_first'] = "Oldest First";
$lang['price_low_to_high'] = "Price - Low To High";
$lang['price_high_to_low'] = "Price - High To Low";
$lang['relevance'] = "Relevance";
$lang['sale'] = "Sale";
$lang['view'] = "View";
$lang['back_to_top'] = "Back to top";
$lang['go_to_shop'] = "Go to Shop";
$lang['details'] = "Details";
$lang['remove_from_favorite'] = "Remove from Favorite";
$lang['specification'] = "Specifications";
$lang['rating'] = "Rating";
$lang['ratings'] = "Ratings";
$lang['related_products'] = "Related Products";
$lang['old_password'] = "Old Password";
$lang['new_password'] = "New Password";
$lang['confirm_new_password'] = "Confirm New Password";
$lang['reset'] = "Reset";
$lang['update_profile'] = "Update Profile";
$lang['transactions'] = "Transactions";
$lang['newsletter'] = "Newsletter";
$lang['useful_links'] = "Useful Links";
$lang['subscribe'] = "Subscribe";
$lang['follow_us'] = "Follow us";
$lang['find_us'] = "Find Us";
$lang['call_us'] = "Call Us";
$lang['mail_us'] = "Mail Us";
$lang['forgot_password'] = "Forgot Password";
$lang['see_all'] = "See All";
$lang['sort_by'] = "Sort By";
$lang['show'] = "Show";
$lang['product_listing'] = "Product Listing";
$lang['balance'] = "Balance";
$lang['enter_valid_number'] = "Enter a valid number / Email";
$lang['clear_cart'] = "Clear Cart";
$lang['product'] = "Product";
$lang['cart_total'] = "Cart Total";
$lang['go_to_checkout'] = "Go To Checkout";
$lang['billing_details'] = "Billing Details";
$lang['wallet_balance'] = "Wallet Balance";
$lang['available_balance'] = "Available Balance";
$lang['payment_method'] = "Payment Method";
$lang['account_details'] = "Account Details";
$lang['account_name'] = "Account Name";
$lang['account_number'] = "Account Number";
$lang['bank_name'] = "Bank Name";
$lang['bank_code'] = "Bank Code";
$lang['extra_details'] = "Extra Details";
$lang['order_summary'] = "Order Summary";
$lang['qty'] = "Qty";
$lang['promocode'] = "Promo Code";
$lang['see_all_offers'] = "See All Offers";
$lang['place_order'] = "Place Order";
$lang['thank_you_for_shopping'] = "Thank You For Shopping";
$lang['continue_shopping'] = "Continue Shopping";
$lang['shipping_policy'] = "Shipping Policy";
$lang['return_policy'] = "Return Policy";
$lang['payment_cancelled_description'] = "Payment Cancelled Description";
$lang['pick_your_favorite_color'] = "Pick Your Favorite Color";
$lang['pick_your_theme'] = "Pick Your Theme";
$lang['modern_theme'] = "Modern Theme";
$lang['classic_theme'] = "Classic Theme";
$lang['welcome_back'] = "Welcome Back";
$lang['fill_your_email_and_password_to_sign_in'] = "Fill your email and password to sign in.";
$lang['password'] = "Password";
$lang['dont_have_an_account'] = "Don\'t have an account?";
$lang['Sign_up_here'] = "Sign up Here";
$lang['registration_takes_less_than_a_minute'] = "Registration takes less than a minute.";
$lang['enter_mobile_number_or_email'] = "Enter Mobile Number / Email";
$lang['enter_mobile_number'] = "Enter Mobile Number";
$lang['buy_now'] = "Buy Now";
$lang['email_us'] = "Email Us";
$lang['blogs'] = "Blogs";
$lang['become_a_seller'] = "Become a Seller";
$lang['seller'] = "seller";
$lang['check_availability'] = "Check Availability";
$lang['go_to_cart'] = "Go To Cart ";
$lang['chat_with'] = "Chat With ";
$lang['cod'] = "COD ";
$lang['no_cancellation'] = "No Cancellation";
$lang['no_returnable'] = "No Returnable ";
$lang['product_details'] = "Product Details ";
$lang['made_in'] = " Made In ";
$lang['description'] = " Description ";
$lang['sold_by'] = "Sold By ";
$lang['zipcode'] = "Zipcode";
$lang['tags'] = "Tags";
$lang['hello'] = "Hello";
$lang['add_money'] = "Add Money";
$lang['withdraw_money'] = "Withdraw money";
$lang['amount'] = "Amount ";
$lang['status'] = "Status ";
$lang['date'] = "Date ";
$lang['type_message'] = "Type Message";
$lang['enter_amount'] = "Enter Amount ";
$lang['refill'] = "Refill ";
$lang['add_money_to_wallet'] = "Add money to wallet ";
$lang['enter_bank_details'] = "Enter bank details ";
$lang['withdraw'] = "Withdraw";
$lang['transaction_id'] = "Transaction ID";
$lang['add_to_wishlist'] = "Add to wishlist";
$lang['quick_view'] = "Quick View";
$lang['reach_out_to_us_from_our_contact_form_and_we_will_get_back_to_you_shortly'] = " Reach out to us from our contact form and we will get back to you shortly.";
$lang['search_your_blog'] = "Search your blog";
$lang['seller_registration'] = "Seller Registration";
$lang['personal_details'] = "Personal Details";
$lang['seller_name'] = "Seller Name";
$lang['enter_email'] = "Enter E-mail";
$lang['address_proof'] = "Address Proof";
$lang['authorized_signature'] = "Authorized Signature";
$lang['national_identity_card'] = "National Identity Card";
$lang['store_details'] = "Store Details";
$lang['Logo'] = "Logo";
$lang['url'] = "URL";
$lang['store_description'] = "Store Description";
$lang['store_tax_details'] = "Store Tax Details";
$lang['tax_name'] = "Tax Name";
$lang['tax_number'] = "Tax Number";
$lang['pan_number'] = "PAN Number";
$lang['bank_details'] = "Bank Details";
$lang['personal_or_store_pan'] = "Personal or Stores PAN Number";
$lang['store_name'] = "Store Name";
$lang['look_like_you_are_lost'] = "Look like you\\\\\\\'re lost";
$lang['the_page_you_are_looking_for_is_not_available_so_please_check_your_url'] = "the page you are looking for is not available, so please check your URL!";
$lang['select_category'] = "Select Category";
$lang['read_more'] = "Read More >>";
$lang['out_of_stock'] = "Out Of Stock";
$lang['remove_from_cart'] = "Remove From Cart";
$lang['no_items_found'] = "No Items Added Yet In Cart.";
$lang['no_category_found'] = "No Category Found";
$lang['label_search_result'] = "Search Result";
$lang['search'] = "Search";
$lang['personal_chat'] = "Personal Chat";
$lang['add_address'] = "Add Address";
$lang['promocodes'] = "Promocodes";
$lang['delivery_charge_without_cod'] = "Delivery Charge without COD :";
$lang['delivery_charge_with_cod'] = "Delivery Charge with COD :";
$lang['estimate_date'] = "Estimated Delivery Date : ";
$lang['net_amount'] = "Net Amount";
$lang['items_in_cart'] = " Item(s) in Cart";
$lang['special_note_for_order'] = " Special Note for Order";
$lang['no_items_to_compare'] = " No items to compare";
$lang['no_faqs_found'] = "No FAQs Found";
$lang['no_favorite_products_found'] = "No Favorite Products Found";
$lang['it_seems_there_are_no_chats_available_at_the_moment'] = "It seems there are no chats available at the moment";
$lang['support_chat'] = "Support Team";
$lang['brands'] = "Brands";
$lang['no_support_team_available'] = "No support team available";
$lang['support_tickets'] = "Support Tickets";
$lang['bank_payment_receipt'] = "Bank Payment Receipt";
$lang['pending'] = "Pending";
$lang['rejected'] = "Rejected";
$lang['accepted'] = "Accepted";
$lang['invalid_value'] = "Invalid Value";
$lang['courier_agency'] = "Courier Agency";
$lang['tracking_id'] = "Tracking Id";
$lang['send_bank_payment_receipt'] = "Send Bank Payment Receipt";
$lang['click_here_to_trace_the_order'] = "click here to trace the order";
$lang['copy_this_tracking_id_and_trace_your_order_with_courier_agency'] = "Copy this Tracking ID and trace your order with Courier Agency.";
$lang['download'] = "Download";
$lang['you_will_receive_this_item_from_seller_via_email'] = "You will receive this item from seller via email";
$lang['price_details'] = "Price Details";
$lang['no_orders_found'] = "No Order placed Yet";
$lang['via'] = "Via";
$lang['reorder'] = "Reorder";
$lang['try_again'] = "Try Again";
$lang['wallet_recharged'] = "Wallet Recharged";
$lang['wallet_recharged_successfully'] = "Wallet Recharged Successfully";
$lang['return_to_wallet'] = "Return To Wallet";
$lang['no_products_found'] = "No Products Found";
$lang['item(s)_sold_in_last_30_days'] = "item(s) sold in last 30 days";
$lang['people_have_added_this_to_cart'] = "people have added this to cart";
$lang['people_have_added_to_wishlist'] = "people have added to wishlist";
$lang['veg'] = "Veg";
$lang['non_veg'] = "Non Veg";
$lang['product_is'] = "Product is";
$lang['delivarable_on'] = "Delivarable on";
$lang['order_from_whatsapp'] = "Order From Whatsapp";
$lang['cancelable_till'] = "Cancelable till";
$lang['days_returnable'] = "Days Returnable";
$lang['guarantee'] = "Guarantee";
$lang['warranty'] = "Warranty";
$lang['add_faq'] = "Add FAQ";
$lang['enter_your_question_here'] = "Enter Your Question Here";
$lang['answer_by'] = "Answer By";
$lang['user_review_images'] = "User Review Images";
$lang['reviews_for_this_product'] = "Reviews For this Product";
$lang['edit_your_review'] = "Edit Your Review";
$lang['add_your_review'] = "Add Your Review";
$lang['your_rating'] = "Your Rating";
$lang['your_review'] = "Your Review";
$lang['invite_your_friends_to_join_and_get_the_reward_as_soon'] = "Invite your friends to join and get the reward as soon as your friend places his first order";
$lang['tap_to_copy'] = "Tap to copy";
$lang['pay_transaction_id'] = "Payment Transaction ID";
$lang['reopend'] = "Reopened";
$lang['closed'] = "Closed";
$lang['resolved'] = "Resolved";
$lang['opened'] = "Opened";
$lang['assignee'] = "Assignee";
$lang['create_a_ticket'] = "Create a ticket";
$lang['customer_support'] = "Customer Support";
$lang['view_blog'] = "View blog";
$lang['withdrawal_request'] = "Withdrawal requests";
$lang['wallet_transaction'] = "Wallet transaction";
$lang['refer_and_earn'] = "Refer and Earn";
$lang['friends_code'] = "Friends Code";
$lang['order_tracking_url'] = "Order Tracking URL";
$lang['shiprocket_order_tracking_url'] = "Shiprocket Order Tracking URL";
$lang['order_tracking_details'] = "Order Tracking Details";
$lang['profile_image'] = "Profile Image";
$lang['ci_csrf_token'] = "";
$lang['0'] = "item(s) sold in last 30 days";

==> Code%20v4.0.2.zip: Code v4.0.2/application/language/english/web_labels_lang.php <==
<?php defined('BASEPATH') OR exit('No direct script access allowed');


$lang['id'] = "Id";
$lang['menu'] = "Menu";
$lang['products'] = "Products";
$lang['my_account'] = "My Account";
$lang['my_orders'] = "My Orders";
$lang['favorite'] = "Favorite";
$lang['login'] = "Login";
$lang['register'] = "Register";
$lang['about_us'] = "About Us";
$lang['contact_us'] = "Contact Us";
$lang['logout'] = "Logout";
$lang['language'] = "Language";
$lang['shopping_cart'] = "Shopping Cart";
$lang['close'] = "Close";
$lang['return_to_shop'] = "Return To Shop";
$lang['empty_cart_message'] = "Your Cart Is Empty";
$lang['view_cart'] = "View Cart";
$lang['faq'] = "FAQs";
$lang['pages'] = "Pages";
$lang['social_media'] = "Social Media";
$lang['terms_and_condition'] = "Terms & Condition";
$lang['privacy_policy'] = "Privacy Policy";
$lang['reviews'] = "Reviews";
$lang['add_to_cart'] = "Add to Cart";
$lang['add_to_favorite'] = "Add to Favorite";
$lang['cancel'] = "Cancel";
$lang['send_otp'] = "Send OTP";
$lang['submit'] = "Submit";
$lang['home'] = "Home";
$lang['name'] = "Name";
$lang['mobile_number'] = "Mobile Number";
$lang['address'] = "Address";
$lang['city'] = "City";
$lang['select_city'] = "Select City";
$lang['select_area'] = "Select Area";
$lang['area'] = "Area";
$lang['pincode'] = "Pincode";
$lang['state'] = "State";
$lang['country'] = "Country";
$lang['type'] = "Type";
$lang['office'] = "Office";
$lang['other'] = "Other";
$lang['alternate_mobile'] = "Alternate Mobile";
$lang['landmark'] = "Landmark";
$lang['action'] = "Action";
$lang['edit_address'] = "Edit Address";
$lang['image'] = "Image";
$lang['price'] = "Price";
$lang['quantity'] = "Quantity";
$lang['total'] = "Total";
$lang['save_for_later'] = "Save For Later";
$lang['remove'] = "Remove";
$lang['subtotal'] = "Subtotal";
$lang['tax'] = "Tax";
$lang['delivery_charge'] = "Delivery Charge";
$lang['grand_total'] = "Grand Total";
$lang['checkout'] = "Checkout";
$lang['move_to_cart'] = "Move to cart";
$lang['category'] = "Category";
$lang['cart'] = "Cart";
$lang['your_cart'] = "Your cart";
$lang['promo_code'] = "Promo code";
$lang['redeem'] = "Redeem";
$lang['clear'] = "Clear";
$lang['billing_address'] = "Billing address";
$lang['preferred_delivery_date_time'] = "Preferred Delivery Date / Time";
$lang['select_payment_method'] = "Select Payment Method";
$lang['cash_on_delivery'] = "Cash On Delivery";
$lang['create_a_new_address'] = "Create a New Address";
$lang['shipping_address'] = "Shipping Address";
$lang['save'] = "Save";
$lang['username'] = "Username";
$lang['email'] = "Email";
$lang['subject'] = "Subject";
$lang['message'] = "Message";
$lang['send_message'] = "Send Message";
$lang['dashboard'] = "Dashboard";
$lang['profile'] = "Profile";
$lang['orders'] = "Orders";
$lang['notification'] = "Notification";
$lang['wallet'] = "Wallet";
$lang['transaction'] = "Transaction";
$lang['no_favorite_product_message'] = "No Favorite Products Found";
$lang['amazing_categories'] = "Amazing Categories";
$lang['view_more'] = "View More";
$lang['mobile_app'] = "Mobile App";
$lang['order_id'] = "Order ID";
$lang['place_on'] = "Place On";
$lang['invoice'] = "Invoice";
$lang['back_to_list'] = "Back to List";
$lang['return'] = "Return";
$lang['shipping_details'] = "Shipping Details";
$lang['total_order_price'] = "Total Order Price";
$lang['promocode_discount'] = "Promocode Discount";
$lang['wallet_used'] = "Wallet Used";
$lang['final_total'] = "Final Total";
$lang['view_details'] = "View Details";
$lang['payment_cancelled'] = "Payment Cancelled / Failed";
$lang['payment_cancelled_message'] = "It seems like payment process is failed or cancelled.Please Try again.";
$lang['payment_completed'] = "Payment Complete";
$lang['payment_completed_message'] = "Payment Completed Succesfully";
$lang['thank_you_for_shopping_with_us'] = "Thank you for Shopping with Us";
$lang['filter'] = "Filter";
$lang['top_rated'] = "Top Rated";
$lang['newest_first'] = "Newest First";
$lang['oldest_first'] = "Oldest First";
$lang['price_low_to_high'] = "Price - Low To High";
$lang['price_high_to_low'] = "Price - High To Low";
$lang['releavance'] = "Relevance";
$lang['sale'] = "Sale";
$lang['view'] = "View";
$lang['back_to_top'] = "Back to top";
$lang['go_to_shop'] = "Go to Shop";
$lang['details'] = "Details";
$lang['remove_from_favorite'] = "Remove from Favorite";
$lang['specification'] = "Specifications";
$lang['rating'] = "Rating";
$lang['related_products'] = "Related Products";
$lang['old_password'] = "Old Password";
$lang['new_password'] = "New Password";
$lang['confirm_new_password'] = "Confirm New Password";
$lang['reset'] = "Reset";
$lang['update_profile'] = "Update Profile";
$lang['transactions'] = "Transactions";
$lang['is_rtl'] = "1";
